@@ -17,21 +17,19 @@ def DecToBin(num):
         num = int(num)
         while num > 0:
             if num % 2 != 0:
-                List.append('1')
+                List += '1'
             else:
-                List.append('0')
+                List += '0'
             num = num // 2
-        return ''.join(reversed(List))
+        return ''.join(List[::-1])
     except ValueError:
         return ValueErrorMSG(num, '10 decimal', False)
-
 def BinToDec(num):
     answer = 0
     try:
         if isinstance(num, float):
             return 'Error: float\n{} is a float not a base {}'.format(num, '2 binary')
-        num = int(num)
-        num = ''.join(reversed(str(num)))
+        num = ''.join(str(num)[::-1])
         for _ in range(len(num)):
             if num[_] == '1':
                 answer += 2 ** _
@@ -40,9 +38,8 @@ def BinToDec(num):
             else:
                 return "Error: Not Binary\n{} in {} makes it not a base 2 binary".format(num[_], ''.join(reversed(num)))
         return answer
-    except ValueError:
+    except TypeError:
         return ValueErrorMSG(num, '2 binary', False)
-
 def DecToHex(num):
     remainder = []
     answer = []
@@ -51,23 +48,26 @@ def DecToHex(num):
     try:
         num = int(num)
         while num > 0:
-            remainder.append(num % 16)
+            remainder += [num % 16]
             num = num // 16
         for _ in remainder:
-            answer.append(Hexadecimal[_])
-        return ''.join(reversed(answer))
+            answer += [Hexadecimal[_]]
+        return ''.join(answer[::-1])
     except ValueError:
         return ValueErrorMSG(num, '10 decimal', False)
-
 def HexToDec(num):
     num = str(num).upper()
-    count = 0
     answer = 0
+    count = 0
     for _ in num:
         if _ not in Hexadecimal:
             return ValueErrorMSG(num, '16 hexadecimal', True)
-    ''.join(reversed(str(num))).upper()
+    num = num[::-1]
     for _ in num:
         answer += (Hexadecimal.index(_) * 16 ** count)
         count += 1
-    return answer
\ No newline at end of file
+    return answer
+def HexToBin(num):
+    return DecToBin(HexToDec(num))
+def BinToHex(num):
+    return DecToHex(BinToDec(num))
\ No newline at end of file
